package com.ruoyi.manage.service;

import java.util.List;
import com.ruoyi.manage.domain.BaseLocation;

/**
 * 库位信息维护Service接口
 * 
 * @author wh
 * @date 2023-12-11
 */
public interface IBaseLocationService 
{
    /**
     * 查询库位信息维护
     * 
     * @param objid 库位信息维护主键
     * @return 库位信息维护
     */
    public BaseLocation selectBaseLocationByObjid(Long objid);

    /**
     * 查询库位信息维护列表
     * 
     * @param baseLocation 库位信息维护
     * @return 库位信息维护集合
     */
    public List<BaseLocation> selectBaseLocationList(BaseLocation baseLocation);

    /**
     * 新增库位信息维护
     * 
     * @param baseLocation 库位信息维护
     * @return 结果
     */
    public int insertBaseLocation(BaseLocation baseLocation);

    /**
     * 修改库位信息维护
     * 
     * @param baseLocation 库位信息维护
     * @return 结果
     */
    public int updateBaseLocation(BaseLocation baseLocation);

    /**
     * 批量删除库位信息维护
     * 
     * @param objids 需要删除的库位信息维护主键集合
     * @return 结果
     */
    public int deleteBaseLocationByObjids(String objids);

    /**
     * 删除库位信息维护信息
     * 
     * @param objid 库位信息维护主键
     * @return 结果
     */
    public int deleteBaseLocationByObjid(Long objid);
}
